clear

% Discretización espacial
n = 1000;
x=linspace(0,1,n).'; dx=1e-3;

% Condiciones iniciales
u1=sin(2*pi*x); 
u2=sin(2*pi*x); 

% Elección de nu
nu1 = 0.9;         % estable
nu2 = 1.01;         % inestable

% Matrices del problema de Dirichlet para u_t + u_x = 0
M = @(nu) toeplitz([1-nu,nu,zeros(1,n-2)],[1-nu,zeros(1,n-1)]);

M1 = M(nu1);
M2 = M(nu2);

% Calculamos radio espectral
rho1 = max(abs(eig(M1)));
rho2 = max(abs(eig(M2)));

% Títulos para los plots
str1 = ['nu=', num2str(nu1), ' rho(M1)=', num2str(rho1)];
str2 = ['nu=', num2str(nu2), ' rho(M2)=', num2str(rho2)];

for i=1:900; 
    
    % Iteraciones con M1 (estable)
    u1 = M1*u1;
    
    % Iteraciones con M2 (inestable)
    u2 = M2*u2;
          
    % Gráficos
    subplot(2,1,1); 
        plot(x,u1); 
        axis([0,1,min([-1;u1]),max([1;u1])]); 
        title(str1,'FontSize',30)
    
    subplot(2,1,2); 
        plot(x,u2); 
        axis([0,1,min([-1;u1]),max([1;u2])]); 
        title(str2,'FontSize',30)
    
    drawnow; 
end